@@ -11,7 +11,7 @@ def main(domain, elastic):
     bases = buscabases.listarbases(domain)
     (listabases, listaregs) = buscaregistro.listarregistros(domain, bases)
     if len(listaregs) == 0:
-    	logger.info ('Não existem registros para serem indexados')
+        logger.info ('Não existem registros para serem indexados')
     else:
-    	logger.info (str(len(listaregs)) + ' registros serão indexados')
-    	indexa.indexar(domain, elastic, listabases, listaregs)
\ No newline at end of file
+        logger.info ('Existem ' + str(len(listaregs)) + ' registros ainda não indexados')
+        indexa.indexar(domain, elastic, listabases, listaregs)
\ No newline at end of file
