@@ -7,7 +7,7 @@ def listarbases(domain):
     """Função que lista todas as bases"""
     
     values = {'$$':'{"select":["nome_base"]}'}
-    url = domain + 'base'
+    url = domain + '/api/base'
     
     recebe = get(url, params=values)
     json_resp = recebe.json()
