@@ -9,7 +9,7 @@ def listarregistros(domain, bases):
     listaregs = []
     values = {'$$':'{"select":["id_reg"],"filters":[{"field":"dt_index_tex","term":null,"operation":"="}]}'}
     for x in bases:
-        url = domain + 'reg/' + x['nome_base']
+        url = domain + '/api/reg/' + x['nome_base']
             
         recebe = get(url, params=values)
         json_resp = recebe.json()
