@@ -13,13 +13,14 @@ def indexar(domain, elastic, listabases, listaregs):
     es = ElasticSearch(elastic)
     for reg, base in zip(listaregs, listabases):
         urles = elastic + base + '/' + base + '/' + str(reg)
-        urlrest = domain + 'reg/' + base + '/' + str(reg)
+        urlrest = domain + '/api/reg/' + base + '/' + str(reg)
         urlfull = urlrest + '/full'
         
         recebe = get(urlfull)
         jsonfull = recebe.json()
-        if '_status' in jsonfull and '_error_message' in jsonfull and '_request' in jsonfull and '_path' in jsonfull:
-            logger.error (urlrest + 'não pode ser indexado pelo seguinte motivo: ' + jsonfull['_status'] + jsonfull['_error_message'])
+        erro = '_status' in jsonfull and '_error_message' in jsonfull and '_request' in jsonfull and '_path' in jsonfull
+        if erro and len(jsonfull) == 4:
+            logger.error (urlrest + 'não pode ser indexado - ' + str(jsonfull['_status']) + ': ' + jsonfull['_error_message'])
         else:
             es.index(base,base, jsonfull, id=reg)
             logger.info (urles + ' indexado com sucesso!')
